#!/usr/bin/ksh
# =======================================================================
#
#                   Jet Propulsion Laboratory
#
#                  Atmospheric InfraRed Sounder
#
#      Copyright (c) 2000 - California Institute of Technology
#              U.S. Government Sponsorship under NASA
#                Contract NAS7-1270 is acknowledged
# !PROLOG ==================================================================
#
#
#------------------------------------------------------------------------------
#
# 1. DISCLAIMER
#    THE SOFTWARE AND/OR RELATED MATERIALS ARE PROVIDED "AS-IS" WITHOUT
#    WARRANTY OF ANY KIND INCLUDING ANY WARRANTIES OF PERFORMANCE OR
#    MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE OR PURPOSE (AS SET FORTH
#    IN UCC 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE LICENSED
#    PRODUCT, HOWEVER USED.
#
#    IN NO EVENT SHALL CALTECH/JPL BE LIABLE FOR ANY DAMAGES AND/OR COSTS,
#    INCLUDING BUT NOT LIMITED TO INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY
#    KIND, INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
#    REGARDLESS OF WHETHER CIT/JPL SHALL BE ADVISED, HAVE REASON TO KNOW,
#    OR IN FACT SHALL KNOW OF THE POSSIBILITY.
#
#    USER BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF THE SOFTWARE
#    AND/OR RELATED MATERIALS.
#
# 2. The user shall comply with all applicable U.S. export control laws and
#    regulations.  To the extent that the software is subject to U.S. export
#    control laws and regulations, the user has the responsibility to obtain
#    export licenses or other export authority as may be required before
#    exporting such information to foreign countries or providing access to
#    foreign persons.
#
#------------------------------------------------------------------------------
#
# !Routine/File Name:
#
#       L1B_VIS.ksh
#
#
# !Description:
#
#    This is a script to run the Level-1B VIS PGE
#
#    It repeatedly calls the level-1B VIS executable for each granule
#    of data.
#
#    It returns 0 (success) unless all granules fail.
#
#
# !Input Parameters:
#
#    Number of granules to process is read in from the PCF file
#    (specified by $PGS_PC_INFO_FILE) from Logical ID (LID) 1022
#
# !Output Parameters:
#
#    None
#
# !Input/Output Parameters:
#
#    None
#
#
# !Global Variables:
#
#    None
#
#
# !Known Bugs and Limitations:
#
#    None
#
#
# !Revision History:  
#
#    Available through CCC/Harvest.
#
#
# !END ==================================================================

let numGranules=0
let numGranules=`PGS_PC_GetConfigDataCom 1022`
if [ numGranules -le 0 ]; then
   exit 1
fi
# echo  "# granules ="$numGranules

let item=1
let numFailures=0
while [ item -le $numGranules ]; do
   run_level_1B_vis $item
   let RESULT=$?
   run_retcode_msg Level-1B-VIS-gran-$item-of-$numGranules $RESULT
   if [ $RESULT -ne 0 ]; then
      let numFailures=$numFailures+1
   fi
   let item=$item+1
done
# echo "numFailures ="$numFailures

# report number of failures to LogStatus
run_aggregate_final $numFailures $numGranules

# if numFailures < numGranules then at least one run succeeded.
if [ numFailures -ge $numGranules ]; then
   # echo "Reporting FAILURE"
   exit 1
fi

# if LID 1071 "Processing Directives" includes the string "UnCompressed"
# then skip the compression
NOCOMPRESS=`PGS_PC_GetConfigDataCom 1071 | grep "UnCompressed"`
# echo "UnCompressed = " $NOCOMPRESS
if [[ $NOCOMPRESS == "" ]] then
   hrepack_all_fields_1lid.pl 7213
   let RESULT=$?
   run_retcode_msg Compress-L1B-VIS $RESULT
fi
